@@ -16,6 +16,7 @@ from typing import List, Tuple, Any, Union, Optional, Dict
 import pycaret.internal.tabular
 
 from pycaret.internal.tabular import MLUsecase
+from pycaret.loggers.base_logger import BaseLogger
 
 warnings.filterwarnings("ignore")
 
@@ -61,8 +62,9 @@ def setup(
     ] = None,
     html: bool = True,
     session_id: Optional[int] = None,
-    log_experiment: bool = False,
+    log_experiment: Union[bool, str, BaseLogger, List[Union[str, BaseLogger]]] = False,
     experiment_name: Optional[str] = None,
+    experiment_custom_tags: Optional[Dict[str, Any]] = None,
     log_plots: Union[bool, list] = False,
     log_profile: bool = False,
     log_data: bool = False,
@@ -321,27 +323,34 @@ def setup(
 
 
     log_experiment: bool, default = False
-        When set to True, all metrics and parameters are logged on the ``MLFlow`` server.
+        A (list of) PyCaret ``BaseLogger`` or str (one of 'mlflow', 'wandb')
+        corresponding to a logger to determine which experiment loggers to use.
+        Setting to True will use just MLFlow.
+        If ``wandb`` (Weights & Biases) is installed, will also log there.
 
 
     experiment_name: str, default = None
-        Name of the experiment for logging. Ignored when ``log_experiment`` is not True.
+        Name of the experiment for logging. Ignored when ``log_experiment`` is False.
+
+    experiment_custom_tags: dict, default = None
+        Dictionary of tag_name: String -> value: (String, but will be string-ified 
+        if not) passed to the mlflow.set_tags to add new custom tags for the experiment.
 
 
     log_plots: bool or list, default = False
         When set to True, certain plots are logged automatically in the ``MLFlow`` server. 
         To change the type of plots to be logged, pass a list containing plot IDs. Refer
-        to documentation of ``plot_model``. Ignored when ``log_experiment`` is not True.
+        to documentation of ``plot_model``. Ignored when ``log_experiment`` is False.
 
 
     log_profile: bool, default = False
         When set to True, data profile is logged on the ``MLflow`` server as a html file.
-        Ignored when ``log_experiment`` is not True. 
+        Ignored when ``log_experiment`` is False. 
 
 
     log_data: bool, default = False
         When set to True, dataset is logged on the ``MLflow`` server as a csv file.
-        Ignored when ``log_experiment`` is not True.
+        Ignored when ``log_experiment`` is False.
         
 
     silent: bool, default = False
@@ -433,6 +442,7 @@ def setup(
         session_id=session_id,
         log_experiment=log_experiment,
         experiment_name=experiment_name,
+        experiment_custom_tags=experiment_custom_tags,
         log_plots=log_plots,
         log_profile=log_profile,
         log_data=log_data,
@@ -450,6 +460,7 @@ def create_model(
     round: int = 4,
     fit_kwargs: Optional[dict] = None,
     verbose: bool = True,
+    experiment_custom_tags: Optional[Dict[str, Any]] = None,
     **kwargs
 ):
 
@@ -507,6 +518,10 @@ def create_model(
     verbose: bool, default = True
         Status update is not printed when verbose is set to False.
 
+    experiment_custom_tags: dict, default = None
+        Dictionary of tag_name: String -> value: (String, but will be string-ified 
+        if not) passed to the mlflow.set_tags to add new custom tags for the experiment.
+
 
     **kwargs: 
         Additional keyword arguments to pass to the estimator.
@@ -541,6 +556,7 @@ def create_model(
         round=round,
         fit_kwargs=fit_kwargs,
         verbose=verbose,
+        experiment_custom_tags=experiment_custom_tags,
         **kwargs,
     )
 
@@ -1479,7 +1495,7 @@ def get_clusters(
     group_names: Optional[List[str]] = None,
     n_jobs: Optional[int] = -1,
     session_id: Optional[int] = None,
-    log_experiment: bool = False,
+    log_experiment: Union[bool, str, BaseLogger, List[Union[str, BaseLogger]]] = False,
     experiment_name: Optional[str] = None,
     log_plots: Union[bool, list] = False,
     log_profile: bool = False,
